==> lego-web-0.0.55.tgz: package/src/pages/index.js <==
/*
 * 前端页面入口文件
 */
import Vue from 'vue'
import Vuex from 'vuex'
import initVue from 'utils/initVue'
import App from 'components/routed-app'

import ControlList from 'components/pages/control-list'
import ControlEdit from 'components/pages/control-edit'
import loginPage from 'components/login'

import MenuEdit from 'components/pages/menu-edit'

import SchemaList from 'components/pages/schema-list'
import SchemaEdit from 'components/pages/schema-edit'

import LangList from 'components/pages/lang-list'
import LangEdit from 'components/pages/lang-edit'

import LangResList from 'components/pages/lang-res-list'
import LangResEdit from 'components/pages/lang-res-edit'

import ClassList from 'components/pages/class-list'
import ClassEdit from 'components/pages/class-edit'

import Parse from 'parse'
import VueI18n from 'vue-i18n'

import '../../package.json'

/*
 * 引入vuex
 */
Vue.use(Vuex)

/*
 * 实例化store
 */
import filters from 'stores/filter/filter'
import menu from 'stores/basic/menu'

import login from 'stores/login'

import control from 'stores/basic/control'
import table from 'stores/basic/table'
import lang from 'stores/basic/lang'
import tableLangRes from 'stores/basic/table-lang-res'
import dictionary from 'stores/flight/dictionary'

const store = new Vuex.Store({
  modules: {
    filters,
    menu,
    login,
    control,
    table,
    lang,
    tableLangRes,
    dictionary
  }
})

const routes = [
  { path: '/s/control/list', component: ControlList },
  { path: '/s/control/create', component: ControlEdit },
  { path: '/s/control/update/:objectId', component: ControlEdit },

  {
    path: '/login',
    component: loginPage,
    meta: { login: false }
  },

  { path: '/s/menu/update', component: MenuEdit },

  { path: '/s/schema/list', component: SchemaList },
  { path: '/s/schema/create', component: SchemaEdit },
  { path: '/s/schema/update/:objectId', component: SchemaEdit },

  { path: '/s/lang/list', component: LangList },
  { path: '/s/lang/create', component: LangEdit },
  { path: '/s/lang/update/:objectId', component: LangEdit },

  { path: '/s/lang-res/list', component: LangResList },
  { path: '/s/lang-res/create', component: LangResEdit },
  { path: '/s/lang-res/update/:key', component: LangResEdit },

  { path: '/p/:menuId/list', component: ClassList },
  { path: '/p/:menuId/:action/:objectId?', component: ClassEdit }
]

const jQuery = require('jquery')
window.$ = window.jQuery = jQuery
const axios = require('axios')

// Parse.initialize('ibe_api_server', '22786907B697B9005C767068A747F956')
// Parse.serverURL = 'http://13.229.31.119:3000/parse'
Parse._initialize(process.env.APP_ID, process.env.APP_KEY, process.env.MASTER_KEY)
Parse.serverURL = process.env.API_BASE

let i18nOptions = {}
let i18n = new VueI18n(i18nOptions)

let elementLang = {
  en_US: require('element-ui/lib/locale/lang/en').default,
  zh_CN: require('element-ui/lib/locale/lang/zh-CN').default
}

let defaultLang = 'en_US'
let defaultLangId
let currLangName = defaultLang
let currLang = localStorage.getItem('lego-web-lang')
if (currLang) {
  currLang = JSON.parse(currLang)
}
let usingLangs = []
let langQuery = new Parse.Query('LEGO_Lang')
let defaultRes = {}
let currRes = {}
langQuery
  .equalTo('name', defaultLang)
  .find()
  .then(lang => {
    if (lang.length === 0) {
      return Promise.resolve([])
    }
    defaultLangId = lang[0].id
    usingLangs.push({
      __type: 'Pointer',
      className: 'LEGO_Lang',
      objectId: defaultLangId
    })
    if (currLang && usingLangs[0].objectId !== currLang.objectId) {
      usingLangs.push(currLang)
    }
    if (!currLang) {
      localStorage.setItem(
        'lego-web-lang',
        JSON.stringify({
          __type: 'Pointer',
          className: 'LEGO_Lang',
          objectId: defaultLangId
        })
      )
    }
    let langResQuery = new Parse.Query('LEGO_Lang_Res')
    return langResQuery
      .limit(9999)
      .containedIn('lang', usingLangs)
      .include('lang')
      .find()
  })
  .then(resources => {
    for (let item of resources) {
      if (item.get('lang').id === defaultLangId) {
        defaultRes[item.get('key')] = item.get('value')
      }
      if (currLang && item.get('lang').id === currLang.objectId) {
        currLangName = item.get('lang').get('name')
        currRes[item.get('key')] = item.get('value')
      }
    }
    return new Parse.Query('CustomLangRes').find()
  })
  .then(resources => {
    for (let item of resources) {
      item = item.toJSON()
      for (let key of Object.keys(item)) {
        if (key === defaultLang) {
          defaultRes[item.objectId] = item[key]
        }
        if (currLang && key === currLangName) {
          currRes[item.objectId] = item[key]
        }
      }
    }
    i18nOptions = {
      locale: currLangName === 'en_US' ? 'en' : currLangName,
      messages: {
        [defaultLang === 'en_US' ? 'en' : defaultLang]: {
          ...defaultRes,
          ...elementLang[defaultLang]
        },
        [currLangName === 'en_US' ? 'en' : currLangName]: {
          ...defaultRes,
          ...currRes,
          ...elementLang[currLangName]
        }
      },
      fallback: defaultLang === 'en_US' ? 'en' : defaultLang
    }
    i18n = new VueI18n(i18nOptions)
    window.i18n = i18n
    store.commit('lang/setCurr', currLangName)
    /*
     * 实例化vue对象，渲染页面
     * @store  vuex的数据仓库
     * @component  用于渲染的组件
     */
    initVue({
      store,
      component: App,
      i18n,
      route: {
        base: process.env.NODE_ENV === 'production' ? '/cms' : '',
        routes,
        historyMode: 'history',
        beforeEach(to, from, next) {
          if (to.meta && to.meta.login !== false) {
            axios({
              url: process.env.NODE_ENV === 'production' ? '/cms/checkLogin' : '/checkLogin'
            }).then(res => {
              if (res.data.userid) {
                next()
              } else {
                next('/login')
              }
            })
          } else next()
        }
      }
    })
  })

// initVue({
//   store,
//   component: App,
//   i18n,
//   route: {
//     base: process.env.NODE_ENV === 'production' ? '/cms' : '',
//     routes,
//     historyMode: 'history',
//     beforeEach(to, from, next) {
//       next()
//     }
//   }
// })

==> lego-web-0.0.58.tgz: package/src/pages/index.js <==
/*
 * 前端页面入口文件
 */
import Vue from 'vue'
import Vuex from 'vuex'
import initVue from 'utils/initVue'
import App from 'components/routed-app'

import ControlList from 'components/pages/control-list'
import ControlEdit from 'components/pages/control-edit'
import loginPage from 'components/login'

import MenuEdit from 'components/pages/menu-edit'

import SchemaList from 'components/pages/schema-list'
import SchemaEdit from 'components/pages/schema-edit'

import LangList from 'components/pages/lang-list'
import LangEdit from 'components/pages/lang-edit'

import LangResList from 'components/pages/lang-res-list'
import LangResEdit from 'components/pages/lang-res-edit'

import ClassList from 'components/pages/class-list'
import ClassEdit from 'components/pages/class-edit'

import Dashboard from 'components/pages/dashboard'

import Parse from 'parse'
import VueI18n from 'vue-i18n'

import '../../package.json'

/*
 * 引入vuex
 */
Vue.use(Vuex)

/*
 * 实例化store
 */
import filters from 'stores/filter/filter'
import menu from 'stores/basic/menu'

import login from 'stores/login'

import control from 'stores/basic/control'
import table from 'stores/basic/table'
import lang from 'stores/basic/lang'
import tableLangRes from 'stores/basic/table-lang-res'
import dictionary from 'stores/flight/dictionary'

const store = new Vuex.Store({
  modules: {
    filters,
    menu,
    login,
    control,
    table,
    lang,
    tableLangRes,
    dictionary
  }
})

const routes = [
  { path: '/s/control/list', component: ControlList },
  { path: '/s/control/create', component: ControlEdit },
  { path: '/s/control/update/:objectId', component: ControlEdit },

  {
    path: '/login',
    component: loginPage,
    meta: { login: false }
  },

  { path: '/s/menu/update', component: MenuEdit },

  { path: '/s/schema/list', component: SchemaList },
  { path: '/s/schema/create', component: SchemaEdit },
  { path: '/s/schema/update/:objectId', component: SchemaEdit },

  { path: '/s/lang/list', component: LangList },
  { path: '/s/lang/create', component: LangEdit },
  { path: '/s/lang/update/:objectId', component: LangEdit },

  { path: '/s/lang-res/list', component: LangResList },
  { path: '/s/lang-res/create', component: LangResEdit },
  { path: '/s/lang-res/update/:key', component: LangResEdit },

  { path: '/p/:menuId/list', component: ClassList },
  { path: '/p/:menuId/:action/:objectId?', component: ClassEdit },

  {
    path: '/',
    component: Dashboard
  }
]

const jQuery = require('jquery')
window.$ = window.jQuery = jQuery
const axios = require('axios')

// Parse.initialize('ibe_api_server', '22786907B697B9005C767068A747F956')
// Parse.serverURL = 'http://13.229.31.119:3000/parse'
Parse._initialize(process.env.APP_ID, process.env.APP_KEY, process.env.MASTER_KEY)
Parse.serverURL = process.env.API_BASE

let i18nOptions = {}
let i18n = new VueI18n(i18nOptions)

let elementLang = {
  en_US: require('element-ui/lib/locale/lang/en').default,
  zh_CN: require('element-ui/lib/locale/lang/zh-CN').default
}

let defaultLang = 'en_US'
let defaultLangId
let currLangName = defaultLang
let currLang = localStorage.getItem('lego-web-lang')
if (currLang) {
  currLang = JSON.parse(currLang)
}
let usingLangs = []
let langQuery = new Parse.Query('LEGO_Lang')
let defaultRes = {}
let currRes = {}
langQuery
  .equalTo('name', defaultLang)
  .find()
  .then(lang => {
    if (lang.length === 0) {
      return Promise.resolve([])
    }
    defaultLangId = lang[0].id
    usingLangs.push({
      __type: 'Pointer',
      className: 'LEGO_Lang',
      objectId: defaultLangId
    })
    if (currLang && usingLangs[0].objectId !== currLang.objectId) {
      usingLangs.push(currLang)
    }
    if (!currLang) {
      localStorage.setItem(
        'lego-web-lang',
        JSON.stringify({
          __type: 'Pointer',
          className: 'LEGO_Lang',
          objectId: defaultLangId
        })
      )
    }
    let langResQuery = new Parse.Query('LEGO_Lang_Res')
    return langResQuery
      .limit(9999)
      .containedIn('lang', usingLangs)
      .include('lang')
      .find()
  })
  .then(resources => {
    for (let item of resources) {
      if (item.get('lang').id === defaultLangId) {
        defaultRes[item.get('key')] = item.get('value')
      }
      if (currLang && item.get('lang').id === currLang.objectId) {
        currLangName = item.get('lang').get('name')
        currRes[item.get('key')] = item.get('value')
      }
    }
    return new Parse.Query('CustomLangRes').limit(9999).find()
  })
  .then(resources => {
    for (let item of resources) {
      item = item.toJSON()
      for (let key of Object.keys(item)) {
        if (key === defaultLang) {
          defaultRes[item.objectId] = item[key]
        }
        if (currLang && key === currLangName) {
          currRes[item.objectId] = item[key]
        }
      }
    }
    i18nOptions = {
      locale: currLangName === 'en_US' ? 'en' : currLangName,
      messages: {
        [defaultLang === 'en_US' ? 'en' : defaultLang]: {
          ...defaultRes,
          ...elementLang[defaultLang]
        },
        [currLangName === 'en_US' ? 'en' : currLangName]: {
          ...defaultRes,
          ...currRes,
          ...elementLang[currLangName]
        }
      },
      fallback: defaultLang === 'en_US' ? 'en' : defaultLang
    }
    i18n = new VueI18n(i18nOptions)
    window.i18n = i18n
    store.commit('lang/setCurr', currLangName)
    /*
     * 实例化vue对象，渲染页面
     * @store  vuex的数据仓库
     * @component  用于渲染的组件
     */
    initVue({
      store,
      component: App,
      i18n,
      route: {
        base: process.env.NODE_ENV === 'production' ? '/cms' : '',
        routes,
        historyMode: 'history',
        beforeEach(to, from, next) {
          if (to.meta && to.meta.login !== false) {
            axios({
              url: process.env.NODE_ENV === 'production' ? '/cms/checkLogin' : '/checkLogin'
            }).then(res => {
              if (res.data.userid) {
                next()
              } else {
                next('/login')
              }
            })
          } else next()
        }
      }
    })
  })

// initVue({
//   store,
//   component: App,
//   i18n,
//   route: {
//     base: process.env.NODE_ENV === 'production' ? '/cms' : '',
//     routes,
//     historyMode: 'history',
//     beforeEach(to, from, next) {
//       next()
//     }
//   }
// })
